@@ -8,7 +8,7 @@ use LWP::UserAgent;
 use JSON;
 use List::Util qw(first);
 
-our $VERSION = 0.3;
+our $VERSION = 0.4;
 
 sub new {
     my ($class, %params) = @_;
@@ -191,7 +191,7 @@ sub download_scan {
 
     my $response = $self->{agent}->get(
         $self->{url} . "/scans/$scan_id/export/$file_id/download",
-        ($params{filename} ? ":content_file => $params{filename}" : "")
+        $params{filename} ? (':content_file' => $params{filename}) : ()
     );
 
     if ($response->is_success()) {
@@ -485,17 +485,21 @@ using REST interface.
     );
 
     $nessus->launch_scan(scan_id => $scan->{id});
-    while ($nessus->get_scan_status(scan_id => $scan->{id} ne 'completed')) {
+    while ($nessus->get_scan_status(scan_id => $scan->{id}) ne 'completed') {
         sleep 10;
     }
 
     my $file_id = $nessus->export_scan(
-        scan_id => $scan_id,
+        scan_id => $scan->{id},
         format  => 'pdf'
     );
 
-    $nessus->download_report(
-        scan_id  => $scan_id,
+    while ($nessus->get_scan_export_status(scan_id => $scan_id, file_id => $file_id) ne 'ready') {
+        sleep 1;
+    }
+
+    $nessus->download_scan(
+        scan_id  => $scan->{id},
         file_id  => $file_id,
         filename => 'localhost.pdf'
     );
